import request from '@/utils/system/request'

// 平台或渠道封禁用户
export function riskConfigList(data) {
    return request({
        url: '/agent-service/risk/configList',
        method: 'post',
        data
    })
}

// 查询风控用户记录 - 风控日志表
export function riskBannedList(data) {
    return request({
        url: '/agent-service/risk/bannedList',
        method: 'post',
        data
    })
}

// 查询解封记录-解封日志表
export function riskDeblockingList(data) {
    return request({
        url: '/agent-service/risk/deblockingList',
        method: 'post',
        data
    })
}

// 修改用户风控状态
export function riskChangeUserStatus(data) {
    return request({
        url: '/agent-service/risk/changeUserStatus',
        method: 'post',
        data
    })
}

// 风控配置关联应用
export function riskRelativeApps(data) {
    return request({
        url: '/agent-service/risk/relativeApp',
        method: 'post',
        data
    })
}

// 保存风控配置
export function riskSaveConfig(data) {
    return request({
        url: '/agent-service/risk/saveConfig',
        method: 'post',
        data
    })
}

// 保存风控配置
export function riskUpdateConfig(data) {
    return request({
        url: '/agent-service/risk/updateConfig',
        method: 'post',
        data
    })
}

// 查询配置字段选项
export function riskOptions(params) {
    return request({
        url: '/agent-service/risk/options',
        method: 'get',
        params
    })
}

// 启用或关闭风控配置
export function riskEnabledConfig(params) {
    return request({
        url: '/agent-service/risk/enabledConfig',
        method: 'get',
        params
    })
}
// 风控配置模板详情
export function riskTemplateView(params) {
    return request({
        url: '/agent-service/risk/templateView',
        method: 'get',
        params
    })
}

// 保存风控配置
export function riskGetByNode(params) {
    return request({
        url: '/agent-service/risk/getByNode',
        method: 'get',
        params
    })
}

